@@ -675,7 +675,7 @@ class Worker:
 
 
 class WorkerException(
-    Exception,
+    BaseException,
 ):
     pass
 
@@ -686,18 +686,6 @@ class WorkerTimedout(
     pass
 
 
-class WorkerHardTimedout(
-    WorkerTimedout,
-):
-    pass
-
-
-class WorkerSoftTimedout(
-    WorkerTimedout,
-):
-    pass
-
-
 class WorkerRequeue(
     WorkerException,
 ):
